[PHP-CVS] com php-src: Fix bug #61454 ext\standard\tests\general_functions\bug49847.phpt fails: ext/standard/tests/general_functions/bug49847.phpt

2012-04-03 Thread Anatoliy Belsky
Commit:14e74aeb579b3400bdf376b5b820fc900b4194ed
Author:Anatoliy Belsky a...@php.net Tue, 3 Apr 2012 13:23:06 +0200
Parents:   94cefaedaf36b681bdf03d89c761f642a28e33e0
Branches:  PHP-5.3 PHP-5.4

Link:   
http://git.php.net/?p=php-src.git;a=commitdiff;h=14e74aeb579b3400bdf376b5b820fc900b4194ed

Log:
Fix bug #61454 ext\standard\tests\general_functions\bug49847.phpt fails

Bugs:
https://bugs.php.net/61454
https://bugs.php.net/49847

Changed paths:
  M  ext/standard/tests/general_functions/bug49847.phpt


Diff:
diff --git a/ext/standard/tests/general_functions/bug49847.phpt 
b/ext/standard/tests/general_functions/bug49847.phpt
index 6312d03..112592d 100644
--- a/ext/standard/tests/general_functions/bug49847.phpt
+++ b/ext/standard/tests/general_functions/bug49847.phpt
@@ -9,7 +9,7 @@ if ($iswin) {
$s = str_repeat(' ', 4097);
$s .= '1';
file_put_contents($f, $s);
-   exec('more ' . $f, $output);
+   exec('type ' . $f, $output);
 } else {
exec(printf %4098d 1, $output);
 }


--
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] com php-src: Fix bug #61481 Test Bug - ext/com_dotnet/tests/bug49192: ext/com_dotnet/tests/bug49192.phpt

2012-04-03 Thread Anatoliy Belsky
Commit:94cefaedaf36b681bdf03d89c761f642a28e33e0
Author:Anatoliy Belsky a...@php.net Tue, 3 Apr 2012 13:07:51 +0200
Parents:   469cd3abf131853b5c727c7eb84754d8383c
Branches:  PHP-5.3 PHP-5.4

Link:   
http://git.php.net/?p=php-src.git;a=commitdiff;h=94cefaedaf36b681bdf03d89c761f642a28e33e0

Log:
Fix bug #61481 Test Bug - ext/com_dotnet/tests/bug49192

Bugs:
https://bugs.php.net/61481
https://bugs.php.net/49192

Changed paths:
  M  ext/com_dotnet/tests/bug49192.phpt


Diff:
diff --git a/ext/com_dotnet/tests/bug49192.phpt 
b/ext/com_dotnet/tests/bug49192.phpt
index 7bae1d7..ccbf237 100644
--- a/ext/com_dotnet/tests/bug49192.phpt
+++ b/ext/com_dotnet/tests/bug49192.phpt
@@ -3,9 +3,23 @@ Bug #49192 (PHP crashes when GC invoked on COM object)
 --SKIPIF--
 ?php 
 if (!extension_loaded(com_dotnet)) print skip COM/.Net support not 
present; ?
+--XFAIL--
+1
 --FILE--
 ?php
 
+// this test fails to load ADO
+//
+// a change in windows longhorn x64(affecting vista, 7, 8, 2008, 2008r2) broke 
ADO.
+//
+// there is a fix available, but user has to install it.
+// given that ADO was deprecated a long time ago in favor of newer APIs,
+// I don't think its worth the trouble of making the user install the fix to
+// get an accurate test run. its better to just not run the test or expect it 
to fail.
+//
+// see: http://support.microsoft.com/kb/2517589
+// see: http://www.infoq.com/news/2011/10/ADO-Win7
+
 $dbConnection = new Com('ADODB.Connection');
 var_dump(gc_collect_cycles());
 ?


--
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] com php-src: Fix bug #61517 random test failure - ext/standard/tests/misc/time_sleep_until_basic.phpt: ext/standard/tests/misc/time_sleep_until_basic.phpt

2012-04-03 Thread Anatoliy Belsky
Commit:469cd3abf131853b5c727c7eb84754d8383c
Author:Anatoliy Belsky a...@php.net Tue, 3 Apr 2012 11:04:52 +0200
Parents:   6d97e28e427d99cfa1ccb8ccdfdeffcc2fcdf383
Branches:  PHP-5.3 PHP-5.4

Link:   
http://git.php.net/?p=php-src.git;a=commitdiff;h=469cd3abf131853b5c727c7eb84754d8383c

Log:
Fix bug #61517 random test failure - 
ext/standard/tests/misc/time_sleep_until_basic.phpt

Bugs:
https://bugs.php.net/61517

Changed paths:
  M  ext/standard/tests/misc/time_sleep_until_basic.phpt


Diff:
diff --git a/ext/standard/tests/misc/time_sleep_until_basic.phpt 
b/ext/standard/tests/misc/time_sleep_until_basic.phpt
index 9ae9128..05cc0e6 100644
--- a/ext/standard/tests/misc/time_sleep_until_basic.phpt
+++ b/ext/standard/tests/misc/time_sleep_until_basic.phpt
@@ -13,7 +13,19 @@ Michele Orselli m...@ideato.it
 ?php
   $time = microtime(true) + 2;
   var_dump(time_sleep_until( (int)$time ));
-  var_dump(microtime(true) = (int)$time);
+  $now = microtime(true);
+  if(substr(PHP_OS, 0, 3) == 'WIN' ) {
+// on windows, time_sleep_until has millisecond accuracy while microtime() 
is accurate
+// to 10th of a second. this means there can be up to a .9 millisecond 
difference
+// which will fail this test. this test randomly fails on Windows and this 
is the cause.
+//
+// fix: round to nearest millisecond 
+// passes for up to .5 milliseconds less, fails for more than .5 
milliseconds
+// should be fine since time_sleep_until() on Windows is accurate to the
+// millisecond(.5 rounded up is 1 millisecond)
+$now = round($now, 3);
+  }
+  var_dump($now = (int)$time);
 ?
 --EXPECT--
 bool(true)


--
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] com php-src: Fix bug #61454 ext\standard\tests\general_functions\bug49847.phpt fails: ext/standard/tests/general_functions/bug49847.phpt

2012-04-03 Thread Anatoliy Belsky
Commit:84be455e22073a011af570c9bf9b79e42349b6a7
Author:Anatoliy Belsky a...@php.net Tue, 3 Apr 2012 13:23:06 +0200
Parents:   c7e9c646eee25711cab04ee2d17390373baa53e5
Branches:  master

Link:   
http://git.php.net/?p=php-src.git;a=commitdiff;h=84be455e22073a011af570c9bf9b79e42349b6a7

Log:
Fix bug #61454 ext\standard\tests\general_functions\bug49847.phpt fails

Bugs:
https://bugs.php.net/61454
https://bugs.php.net/49847

Changed paths:
  M  ext/standard/tests/general_functions/bug49847.phpt


Diff:
diff --git a/ext/standard/tests/general_functions/bug49847.phpt 
b/ext/standard/tests/general_functions/bug49847.phpt
index 6312d03..112592d 100644
--- a/ext/standard/tests/general_functions/bug49847.phpt
+++ b/ext/standard/tests/general_functions/bug49847.phpt
@@ -9,7 +9,7 @@ if ($iswin) {
$s = str_repeat(' ', 4097);
$s .= '1';
file_put_contents($f, $s);
-   exec('more ' . $f, $output);
+   exec('type ' . $f, $output);
 } else {
exec(printf %4098d 1, $output);
 }


--
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] com php-src: Fix bug #61481 Test Bug - ext/com_dotnet/tests/bug49192: ext/com_dotnet/tests/bug49192.phpt

2012-04-03 Thread Anatoliy Belsky
Commit:c7e9c646eee25711cab04ee2d17390373baa53e5
Author:Anatoliy Belsky a...@php.net Tue, 3 Apr 2012 13:07:51 +0200
Parents:   36449bface319cba5dfa11348e80bf8612f25b15
Branches:  master

Link:   
http://git.php.net/?p=php-src.git;a=commitdiff;h=c7e9c646eee25711cab04ee2d17390373baa53e5

Log:
Fix bug #61481 Test Bug - ext/com_dotnet/tests/bug49192

Bugs:
https://bugs.php.net/61481
https://bugs.php.net/49192

Changed paths:
  M  ext/com_dotnet/tests/bug49192.phpt


Diff:
diff --git a/ext/com_dotnet/tests/bug49192.phpt 
b/ext/com_dotnet/tests/bug49192.phpt
index 7bae1d7..ccbf237 100644
--- a/ext/com_dotnet/tests/bug49192.phpt
+++ b/ext/com_dotnet/tests/bug49192.phpt
@@ -3,9 +3,23 @@ Bug #49192 (PHP crashes when GC invoked on COM object)
 --SKIPIF--
 ?php 
 if (!extension_loaded(com_dotnet)) print skip COM/.Net support not 
present; ?
+--XFAIL--
+1
 --FILE--
 ?php
 
+// this test fails to load ADO
+//
+// a change in windows longhorn x64(affecting vista, 7, 8, 2008, 2008r2) broke 
ADO.
+//
+// there is a fix available, but user has to install it.
+// given that ADO was deprecated a long time ago in favor of newer APIs,
+// I don't think its worth the trouble of making the user install the fix to
+// get an accurate test run. its better to just not run the test or expect it 
to fail.
+//
+// see: http://support.microsoft.com/kb/2517589
+// see: http://www.infoq.com/news/2011/10/ADO-Win7
+
 $dbConnection = new Com('ADODB.Connection');
 var_dump(gc_collect_cycles());
 ?


--
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] com php-src: Fix bug #61517 random test failure - ext/standard/tests/misc/time_sleep_until_basic.phpt: ext/standard/tests/misc/time_sleep_until_basic.phpt

2012-04-03 Thread Anatoliy Belsky
Commit:36449bface319cba5dfa11348e80bf8612f25b15
Author:Anatoliy Belsky a...@php.net Tue, 3 Apr 2012 11:04:52 +0200
Parents:   7a2885a5913bcd17e8a862e4f2b86599a6f9153c
Branches:  master

Link:   
http://git.php.net/?p=php-src.git;a=commitdiff;h=36449bface319cba5dfa11348e80bf8612f25b15

Log:
Fix bug #61517 random test failure - 
ext/standard/tests/misc/time_sleep_until_basic.phpt

Bugs:
https://bugs.php.net/61517

Changed paths:
  M  ext/standard/tests/misc/time_sleep_until_basic.phpt


Diff:
diff --git a/ext/standard/tests/misc/time_sleep_until_basic.phpt 
b/ext/standard/tests/misc/time_sleep_until_basic.phpt
index 9ae9128..05cc0e6 100644
--- a/ext/standard/tests/misc/time_sleep_until_basic.phpt
+++ b/ext/standard/tests/misc/time_sleep_until_basic.phpt
@@ -13,7 +13,19 @@ Michele Orselli m...@ideato.it
 ?php
   $time = microtime(true) + 2;
   var_dump(time_sleep_until( (int)$time ));
-  var_dump(microtime(true) = (int)$time);
+  $now = microtime(true);
+  if(substr(PHP_OS, 0, 3) == 'WIN' ) {
+// on windows, time_sleep_until has millisecond accuracy while microtime() 
is accurate
+// to 10th of a second. this means there can be up to a .9 millisecond 
difference
+// which will fail this test. this test randomly fails on Windows and this 
is the cause.
+//
+// fix: round to nearest millisecond 
+// passes for up to .5 milliseconds less, fails for more than .5 
milliseconds
+// should be fine since time_sleep_until() on Windows is accurate to the
+// millisecond(.5 rounded up is 1 millisecond)
+$now = round($now, 3);
+  }
+  var_dump($now = (int)$time);
 ?
 --EXPECT--
 bool(true)


diff --git a/ext/standard/tests/file/popen_pclose_error-win32.phpt 
b/ext/standard/tests/file/popen_pclose_error-win32.phpt
index f81cd52..9f9593c 100644
--- a/ext/standard/tests/file/popen_pclose_error-win32.phpt
+++ b/ext/standard/tests/file/popen_pclose_error-win32.phpt
@@ -17,7 +17,7 @@ if (PHP_DEBUG) die(skip Not Valid for debug builds);
  * Description: Closes process file pointer.
  */
 $file_path = dirname(__FILE__);
-echo *** Testing for error conditions ***\n;
+echo *** Testing for error conditions *** . PHP_EOL;
 var_dump( popen() );  // Zero Arguments
 var_dump( popen(abc.txt) );   // Single Argument
 var_dump( popen(abc.txt, rw) );   // Invalid mode Argument
@@ -26,7 +26,7 @@ $file_handle = fopen($file_path./popen.tmp, w);
 var_dump( pclose($file_handle, $file_handle) );
 pclose($file_handle);
 var_dump( pclose(1) );
-echo \n--- Done ---;
+echo PHP_EOL . PHP_EOL . --- Done ---;
 ?
 --CLEAN--
 ?php
@@ -41,9 +41,9 @@ NULL
 
 Warning: popen() expects exactly 2 parameters, 1 given in %s on line %d
 NULL
-resource(%d) of type (stream)
-'abc.txt' is not recognized as an internal or external command,
-operable program or batch file.
+
+Warning: popen(abc.txt,rw): Invalid argument in %s on line %d
+bool(false)
 
 Warning: pclose() expects exactly 1 parameter, 0 given in %s on line %d
 bool(false)
@@ -54,4 +54,6 @@ bool(false)
 Warning: pclose() expects parameter 1 to be resource, integer given in %s on 
line %d
 bool(false)
 
 Done ---
+
+--- Done ---'abc.txt' is not recognized as an internal or external command,
+operable program or batch file.


--
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] com php-src: Fixed bug #61423 (gzip compression fails).: ext/soap/php_http.c

2012-04-03 Thread Ilia Alshanetsky
Commit:9c5ae9954f40c82ee98038ce3e528185090e4ba1
Author:Ilia Alshanetsky il...@php.net Tue, 3 Apr 2012 08:47:00 
-0400
Parents:   827c446b62ecab6e92b93a9184ba28e581b4d882
Branches:  PHP-5.4

Link:   
http://git.php.net/?p=php-src.git;a=commitdiff;h=9c5ae9954f40c82ee98038ce3e528185090e4ba1

Log:
Fixed bug #61423 (gzip compression fails).

Bugs:
https://bugs.php.net/61423

Changed paths:
  M  ext/soap/php_http.c


Diff:
diff --git a/ext/soap/php_http.c b/ext/soap/php_http.c
index a156488..69deccd 100644
--- a/ext/soap/php_http.c
+++ b/ext/soap/php_http.c
@@ -336,7 +336,7 @@ int make_http_soap_request(zval  *this_ptr,
  n = 3;
ZVAL_STRING(func, gzencode, 0);

smart_str_append_const(soap_headers_z,Content-Encoding: gzip\r\n);
-   ZVAL_LONG(params[2], 1);
+   ZVAL_LONG(params[2], 0x1f);
}
if (call_user_function(CG(function_table), 
(zval**)NULL, func, retval, n, params TSRMLS_CC) == SUCCESS 
Z_TYPE(retval) == IS_STRING) {


--
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php



[PHP-CVS] com karma: Add mails about deleted commits and branch: lib/Git/PostReceiveHook.php lib/Git/ReceiveHook.php

2012-04-03 Thread Alexander Moskaliov
Commit:a103092576b8d9d7ade835308e8d12ff130a59cf
Author:Alexander Moskaliov ir...@php.net Tue, 3 Apr 2012 16:00:42 
+0400
Parents:   410216d61c4f23d552e87741161844685e640b87
Branches:  master

Link:   
http://git.php.net/?p=karma.git;a=commitdiff;h=a103092576b8d9d7ade835308e8d12ff130a59cf

Log:
Add mails about deleted commits and branch

Changed paths:
  M  lib/Git/PostReceiveHook.php
  M  lib/Git/ReceiveHook.php

diff --git a/lib/Git/PostReceiveHook.php b/lib/Git/PostReceiveHook.php
index f524fa6..77396d4 100644
--- a/lib/Git/PostReceiveHook.php
+++ b/lib/Git/PostReceiveHook.php
@@ -82,9 +82,17 @@ class PostReceiveHook extends ReceiveHook
 if ($ref['reftype'] == self::REF_TAG) {
 // tag mail
 $this-sendTagMail($ref['refname'], $ref['changetype'], 
$ref['old'], $ref['new']);
-} elseif ($ref['reftype'] == self::REF_BRANCH  
$ref['changetype'] != self::TYPE_DELETED) {
-// magic populate the $this-revisions
-$this-getBranchRevisions($ref['refname'], $ref['changetype'], 
$ref['old'], $ref['new']);
+} elseif ($ref['reftype'] == self::REF_BRANCH) {
+if ($ref['changetype'] != self::TYPE_DELETED) {
+// magic populate the $this-revisions
+$this-getBranchRevisions($ref['refname'], 
$ref['changetype'], $ref['old'], $ref['new']);
+
+if ($ref['changetype'] == self::TYPE_UPDATED) {
+$this-sendDeletedCommitsMail($ref['refname'], 
$ref['old'], $ref['new']);
+}
+} else {
+$this-sendDeletedBranchMail($ref['refname']);
+}
 }
 }
 
@@ -98,113 +106,135 @@ class PostReceiveHook extends ReceiveHook
 }
 
 }
+
 /**
  * Send mail about branch.
  * Subject: [git] [branch] %PROJECT%: %STATUS% branch %BRANCH_NAME%
  * Body:
- * Branch %BRANCH_NAME% in %PROJECT% was %STATUS%
- * Date: Thu, 08 Mar 2012 12:39:48 +(current mail date)
- *
- * Link: 
http://git.php.net/?p=%PROJECT_PATH%;a=log;h=%SHA_NEW%;hp=%SHA_OLD%
+ * Branch: %BRANCH%
+ * Deleted commits count: %REV_COUNT%
+ * User: %USER%   Thu, 08 Mar 2012 12:39:48 
+
  *
  * --part1--
- * Log:
- *
- * --per commit--
- * Commit: %SHA%
- * Author: %USER%   Thu, 08 Mar 2012 12:39:48 
+
- * Committer: %USER%   Thu, 08 Mar 2012 
12:39:48 +
- * Link: http://git.php.net/?p=%PROJECT_PATH%;a=commitdiff;h=%SHA%
- * Shortlog: %COMMIT_SUBJECT%
- * --/per commit--
- *
+ * Changed paths:
+ * %PATHS%
  * --/part1--
  *
+ * --part2--
+ * Diff:
+ * %DIFF%
+ * --/part2--
+ *
  * @param string $name branch fullname (refs/heads/example)
- * @param int $changeType delete, create or update
  * @param string $oldrev old revision
  * @param string $newrev new revision
- * @return string mail uniq id
  */
-private function sendBranchMail($name, $changeType, $oldrev, $newrev)
+private function sendDeletedCommitsMail($name, $oldrev, $newrev)
 {
 
-$logString = '';
-$status = [self::TYPE_UPDATED = 'update', self::TYPE_CREATED = 
'create', self::TYPE_DELETED = 'delete'];
-$shortname = str_replace('refs/heads/', '', $name);
+$deletedRevisionsCount = 
count($this-getRevisions(escapeshellarg($newrev . '..' . $oldrev)));
 
-// forced push
-if ($changeType == self::TYPE_UPDATED) {
-$replacedRevisions = $this-getRevisions(escapeshellarg($newrev . 
'..' . $oldrev)) ?: false;
-} else {
-$replacedRevisions = false;
-}
-
-if ($changeType != self::TYPE_DELETED) {
+if ($deletedRevisionsCount  0) {
+$shortName = str_replace('refs/heads/', '', $name);
 
-$revisions = $this-getBranchRevisions($name, $changeType, 
$oldrev, $newrev);
+$paths = $this-getChangedPaths(escapeshellarg($newrev . '..' . 
$oldrev), true);
+$pathsString = '';
+foreach ($paths as $path = $action)
+{
+$pathsString .= '  ' . $action . '  ' . $path . \n;
+}
 
-if (count($revisions)) {
+$isTrivialMerge = count($paths) = 0;
+
+if (!$isTrivialMerge) {
+
+$diff =  \Git::gitExec('diff-tree --cc -r -R --no-commit-id 
%s', escapeshellarg($newrev . '..' . $oldrev));
+
+$mail = new \Mail();
+$mail-setSubject($this-emailPrefix . 'del ' . 
$this-getRepositoryShortName() . ': '. implode(' ', array_keys($paths)));
+$mail-setTimestamp(strtotime(date('r')));
+
+$message = 'Branch: ' . $shortName . 

[PHP-CVS] com php-src: Fix bug #61460 popen_close_error-win32 expected output is wrong: ext/standard/tests/file/popen_pclose_error-win32.phpt

2012-04-03 Thread Anatoliy Belsky
Commit:438536e45e1f762fd0f0fe7d9243adb63074e55d
Author:Matt Ficken mattfic...@php.net Tue, 3 Apr 2012 14:19:43 
+0200
@@ -98,113 +106,135 @@ class PostReceiveHook extends ReceiveHook
 /**
- * Send mail about branch.
- * Subject: [git] [branch] %PROJECT%: %STATUS% branch %BRANCH_NAME%
+ * Send mail about force deleted commits.
+ * Subject: del %PROJECT%: %PATHS%
  * Body:
Committer: Anatoliy Belsky a...@php.net  Tue, 3 Apr 2012 14:19:43 +0200
Parents:   14e74aeb579b3400bdf376b5b820fc900b4194ed
Branches:  PHP-5.3 PHP-5.4 master

Link:   
http://git.php.net/?p=php-src.git;a=commitdiff;h=438536e45e1f762fd0f0fe7d9243adb63074e55d

Log:
Fix bug #61460 popen_close_error-win32 expected output is wrong

Bugs:
https://bugs.php.net/61460

Changed paths:
  M  ext/standard/tests/file/popen_pclose_error-win32.phpt


Diff:
--
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php